Module input

Module input 

FASTA/FASTQ input discovery and zero-copy fragment parsing.

Parsers split records at non-ACGT symbols. Borrowed callbacks are preferred by the production partitioner so sequence data does not need to be copied.

Structs

BorrowedSequenceFragment
SequenceFragment

Enums

InputError

Functions

expand_input_paths
normalized_fragment_seq
parse_fragments
parse_fragments_borrowed
parse_fragments_borrowed_with
As parse_fragments_borrowed, but permitted to use inflate_workers threads to decompress block-structured (BGZF) gzip input.