pub struct ColorCoordinate(/* private fields */);Expand description
Compact location of a deduplicated source set in the color repository.
Published coordinates use 8 worker bits and 32 worker-local index bits. The high bit is reserved for concurrent insertion state.
Implementations
Sourceimpl ColorCoordinate
impl ColorCoordinate
pub fn in_process(worker: u64) -> Self
pub fn discovered(worker: u64, index: u64) -> Self
pub fn from_u40(value: u64) -> Self
pub fn is_in_process(self) -> bool
pub fn processing_worker(self) -> u64
pub fn as_u40(self) -> u64
pub fn worker(self) -> usize
pub fn index(self) -> u32