FASTA/FASTQ input discovery and zero-copy fragment parsing.
Parsers split records at non-ACGT symbols. Borrowed callbacks are preferred by the production partitioner so sequence data does not need to be copied.
Structs
Enums
Functions
- expand_
input_ paths - normalized_
fragment_ seq - parse_
fragments - parse_
fragments_ borrowed - parse_
fragments_ borrowed_ with - As
parse_fragments_borrowed, but permitted to useinflate_workersthreads to decompress block-structured (BGZF) gzip input.